@@ -16,9 +16,8 @@ class GenerateContributingCommand(BaseCommand):
     """
     file_name = 'CONTRIBUTING.md'
 
-    @classmethod
-    def get_parser(cls) -> ArgumentParser:
-        parser = cls._get_default_parser()
+    @staticmethod
+    def build_parser(parser) -> ArgumentParser:
         builders.build_config(parser)
         builders.build_output(parser)
         builders.build_other(parser)
