@@ -12,9 +12,8 @@ class GenerateEditorconfigCommand(BaseCommand):
     """Create EditorConfig for project.
     https://editorconfig.org/
     """
-    @classmethod
-    def get_parser(cls) -> ArgumentParser:
-        parser = cls._get_default_parser()
+    @staticmethod
+    def build_parser(parser) -> ArgumentParser:
         builders.build_config(parser)
         builders.build_output(parser)
         builders.build_other(parser)
