@@ -22,9 +22,8 @@ DUMPERS = (
 class ProjectBuildCommand(BaseCommand):
     """Create dist archives for project.
     """
-    @classmethod
-    def get_parser(cls) -> ArgumentParser:
-        parser = cls._get_default_parser()
+    @staticmethod
+    def build_parser(parser) -> ArgumentParser:
         builders.build_config(parser)
         builders.build_from(parser)
         builders.build_resolver(parser)
