@@ -1,5 +1,6 @@
 # built-in
 from contextlib import suppress
+from itertools import chain
 from pathlib import Path
 from typing import Tuple
 
@@ -8,11 +9,12 @@ import attr
 from dephell_discover import Root as PackageRoot
 from dephell_specifier import RangeSpecifier
 from packaging.utils import canonicalize_name
+from packaging.version import parse as parse_version
 
 # app
 from ..cached_property import cached_property
-from .group import Group
 from .author import Author
+from .group import Group
 
 
 @attr.s()
@@ -37,6 +39,7 @@ class RootRelease:
 class RootDependency:
     raw_name = attr.ib(default='root')
     dependencies = attr.ib(factory=list, repr=False)
+    repo = attr.ib(default=None, repr=False)
 
     # additional info strings
     version = attr.ib(default='0.0.0', repr=False)      # Version
@@ -56,7 +59,6 @@ class RootDependency:
     python = attr.ib(default=RangeSpecifier(), repr=False)  # Requires-Python
     readme = attr.ib(default=None, repr=False)              # Description
 
-    repo = None
     applied = False
     locked = False
     compat = True
@@ -67,6 +69,12 @@ class RootDependency:
     def name(self) -> str:
         return canonicalize_name(self.raw_name)
 
+    @property
+    def pep_version(self) -> str:
+        """Returns PEP-formatted version
+        """
+        return str(parse_version(self.version))
+
     @cached_property
     def all_releases(self) -> Tuple[RootRelease]:
         release = RootRelease(
@@ -85,10 +93,26 @@ class RootDependency:
         return (self.group, )
 
     @property
-    def python_compat(self):
+    def python_compat(self) -> bool:
         return True
 
-    def attach_dependencies(self, dependencies):
+    @property
+    def warehouses(self) -> tuple:
+        from ..repositories import WarehouseBaseRepo
+
+        repos = dict()
+        for dep in chain(self.dependencies, [self]):
+            if dep.repo is None:
+                continue
+            if not isinstance(dep.repo, WarehouseBaseRepo):
+                continue
+            for repo in dep.repo.repos:
+                if repo.from_config:
+                    continue
+                repos[repo.name] = repo
+        return tuple(repos.values())
+
+    def attach_dependencies(self, dependencies) -> None:
         self.dependencies.extend(dependencies)
 
     def unlock(self):
@@ -100,11 +124,11 @@ class RootDependency:
     def unapply(self, name: str):
         raise NotImplementedError
 
-    def copy(self):
+    def copy(self) -> 'RootDependency':
         return type(self)(**attr.asdict(self, recurse=False))
 
     @classmethod
-    def get_metainfo(cls, other, *others):
+    def get_metainfo(cls, other, *others) -> 'RootDependency':
         """Merge metainfo, but not dependencies
         """
         merged = attr.asdict(other, recurse=False)
@@ -133,8 +157,8 @@ class RootDependency:
 
         return root
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.name
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return '{cls}({name})'.format(cls=self.__class__.__name__, name=self.name)
