@@ -32,6 +32,7 @@ logger = getLogger('dephell.repositories.warehouse.simple')
 class WarehouseSimpleRepo(WarehouseBaseRepo):
     name = attr.ib(type=str)
     url = attr.ib(type=str)
+    pretty_url = attr.ib(type=str, default='')
     auth = attr.ib(default=None)
 
     prereleases = attr.ib(type=bool, factory=lambda: config['prereleases'])  # allow prereleases
@@ -42,22 +43,9 @@ class WarehouseSimpleRepo(WarehouseBaseRepo):
         # make name canonical
         if self.name in ('pypi.org', 'pypi.python.org'):
             self.name = 'pypi'
-
-        # replace link on pypi api by link on simple index
-        parsed = urlparse(self.url)
-        if parsed.hostname == 'pypi.python.org':
-            hostname = 'pypi.org'
-        else:
-            hostname = parsed.hostname
-        if hostname in ('pypi.org', 'test.pypi.org'):
-            path = '/simple/'
-        else:
-            path = parsed.path
-        self.url = parsed.scheme + '://' + hostname + path
-
-    @property
-    def pretty_url(self) -> str:
-        return self.url
+        if not self.pretty_url:
+            self.pretty_url = self.url
+        self.url = self._get_url(self.url, default_path='/simple/')
 
     def get_releases(self, dep) -> tuple:
         links = self._get_links(name=dep.base_name)
